Index: src/ia32/codegen-ia32.h |
=================================================================== |
--- src/ia32/codegen-ia32.h (revision 3920) |
+++ src/ia32/codegen-ia32.h (working copy) |
@@ -438,8 +438,9 @@ |
// Receiver is passed on the frame and consumed. |
Result EmitNamedLoad(Handle<String> name, bool is_contextual); |
- // Reciever and value are passed on the frame and consumed. |
- Result EmitNamedStore(Handle<String> name); |
+ // If the store is contextual, value is passed on the frame and consumed. |
+ // Otherwise, receiver and value are passed on the frame and consumed. |
+ Result EmitNamedStore(Handle<String> name, bool is_contextual); |
// Receiver and key are passed on the frame and consumed. |
Result EmitKeyedLoad(); |